@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CHUNGA; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/chunga/input.lisp,v 1.12 2007/01/01 23:39:36 edi Exp $
+;;; $Header: /usr/local/cvsrep/chunga/input.lisp,v 1.13 2007/09/06 23:01:27 edi Exp $
 
 ;;; Copyright (c) 2006-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -79,8 +79,9 @@ CHUNKED-INPUT-STREAM."
 (defmethod stream-listen ((stream chunked-input-stream))
   "We first check if input chunking is enabled and if there's
 something in the buffer.  Otherwise we poll the underlying stream."
-  (cond ((and (chunked-stream-input-chunking-p stream)
-              (chunked-input-available-p stream)))
+  (cond ((chunked-stream-input-chunking-p stream)
+         (or (chunked-input-available-p stream)
+             (fill-buffer stream)))
         (t (listen (chunked-stream-input-stream stream)))))
 
 (defmethod fill-buffer ((stream chunked-input-stream))
