@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-USER; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/chunga/packages.lisp,v 1.12 2007/01/01 23:39:36 edi Exp $
+;;; $Header: /usr/local/cvsrep/chunga/packages.lisp,v 1.14 2007/09/18 07:00:39 edi Exp $
 
 ;;; Copyright (c) 2006-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -33,7 +33,9 @@
   (:use :cl :trivial-gray-streams :flexi-streams)
   #+:lispworks
   (:import-from :lw :when-let)
-  (:export :*current-error-message*
+  (:export :*accept-bogus-eols*
+           :*current-error-message*
+           :*treat-semicolon-as-continuation*
            :assert-char
            :chunked-input-stream
            :chunked-input-stream-extensions
