@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CHUNGA; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/chunga/read.lisp,v 1.10 2007/02/08 14:28:03 edi Exp $
+;;; $Header: /usr/local/cvsrep/chunga/read.lisp,v 1.13 2007/10/11 06:56:02 edi Exp $
 
 ;;; Copyright (c) 2006-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -90,21 +90,38 @@ otherwise."
   (assert-char stream #\Linefeed))
 
 (defun read-line* (stream &optional log-stream)
-  "Reads and assembles characters from STREAM until a carriage
-return is read.  Makes sure that the following character is a
-linefeed.  Returns the string of characters read excluding the
-line break.  Additonally logs this string to LOG-STREAM if
-it is not NIL."
-  (let ((result (with-output-to-string (line)
-                  (loop for char = (read-char stream)
-                        until (char= char #\Return)
-                        do (write-char char line))
-                  (assert-char stream #\Linefeed))))
-    (when log-stream
-      (write-line result log-stream)
-      (finish-output log-stream))
-    result))
-        
+  "Reads and assembles characters from STREAM until a carriage return
+is read.  Makes sure that the following character is a linefeed.  If
+*ACCEPT-BOGUS-EOLS* is not NIL, then the function will also accept a
+lone carriage return or linefeed as an acceptable line break.  Returns
+the string of characters read excluding the line break.  Additionally
+logs this string to LOG-STREAM if it is not NIL."
+  (flet ((read-eol ()
+           "Read a CRLF from STREAM. If *accept-bogus-eols* is non-nil
+then accept a lone CR as a valid EOL."
+           (cond (*accept-bogus-eols* 
+                  (assert-char stream #\Return)
+                  (when (eql (peek-char nil stream) #\Linefeed)
+                    (assert-char stream #\Linefeed)))))
+                 (t (assert-crlf stream)))
+    (let ((result
+           (with-output-to-string (line)
+             (loop for char = (read-char stream)
+                   for is-cr-p = (char= char #\Return)
+                   until (or is-cr-p
+                             (and *accept-bogus-eols*
+                                  (char= char #\Linefeed)))
+                   do (write-char char line)
+                   finally (cond ((not *accept-bogus-eols*)
+                                  (assert-char stream #\Linefeed))
+                                 (is-cr-p
+                                  (when (eql (peek-char nil stream) #\Linefeed)
+                                    (read-char stream))))))))                                       
+      (when log-stream
+        (write-line result log-stream)
+        (finish-output log-stream))
+      result)))
+
 (defun trim-whitespace (string)
   "Returns a version of the string STRING where spaces and tab
 characters are trimmed from the start and the end."
@@ -141,7 +158,7 @@ Returns NIL if LINE consists solely of whitespace."
                (unless (zerop (length (trim-whitespace line)))
                  (let ((colon-pos (or (position #\: line :test #'char=)
                                       (error "Couldn't find colon in header line ~S." line))))
-                   (cons (intern (string-upcase (subseq line 0 colon-pos)) :keyword)
+                   (cons (as-keyword (subseq line 0 colon-pos))
                          (trim-whitespace (subseq line (1+ colon-pos)))))))
              (add-header (pair)
                "Adds the name/value cons PAIR to HEADERS.  Takes
@@ -153,10 +170,8 @@ care of multiple headers with the same name."
                         (setf (cdr existing-header)
                               (format nil "~A~:[,~;~]~A"
                                       existing-value
-                                      ;; workaround for bug in some
-                                      ;; Netscape servers (reported by
-                                      ;; John Foderaro)
-                                      (and (eq name :set-cookie)
+                                      (and *treat-semicolon-as-continuation*
+                                           (eq name :set-cookie)
                                            (ends-with-p (trim-whitespace existing-value) ";"))
                                       (cdr pair))))
                        (t (push pair headers))))))             
@@ -235,7 +250,7 @@ value are optional.  If COOKIE-SYNTAX is true, the uses
 READ-COOKIE-VALUE internally."
   (skip-whitespace stream)
   (let ((name (if cookie-syntax
-                (read-cookie-value stream :separators "=")
+                (read-cookie-value stream :separators "=,")
                 (read-token stream))))
     (skip-whitespace stream)
     (cons name
