@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CHUNGA; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/chunga/specials.lisp,v 1.6 2007/01/01 23:39:36 edi Exp $
+;;; $Header: /usr/local/cvsrep/chunga/specials.lisp,v 1.9 2007/09/18 07:00:39 edi Exp $
 
 ;;; Copyright (c) 2006-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -51,6 +51,22 @@ characters unless it is NIL.")
 errors about unexpected characters when *CURRENT-ERROR-MESSAGE*
 is NIL.")
 
+(defvar *accept-bogus-eols* nil
+  "Some web servers do not respond with a correct CRLF line ending for
+HTTP headers but with a lone linefeed or carriage return instead.  If
+this variable is bound to a true value, READ-LINE* will treat a lone
+LF or CR character as an acceptable end of line.  The initial value is
+NIL.")
+
+(defvar *treat-semicolon-as-continuation* nil
+  "According to John Foderaro, Netscape v3 web servers bogusly split
+Set-Cookie headers over multiple lines which means that we'd have to
+treat Set-Cookie headers ending with a semicolon as incomplete and
+combine them with the next header.  This will only be done if this
+variable has a true value, though.")
+
+(pushnew :chunga *features*)
+
 ;; stuff for Nikodemus Siivola's HYPERDOC
 ;; see <http://common-lisp.net/project/hyperdoc/>
 ;; and <http://www.cliki.net/hyperdoc>
