@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CHUNGA; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/chunga/util.lisp,v 1.4 2007/01/01 23:39:36 edi Exp $
+;;; $Header: /usr/local/cvsrep/chunga/util.lisp,v 1.5 2007/10/11 06:56:02 edi Exp $
 
 ;;; Copyright (c) 2006-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -43,3 +43,13 @@ SUFFIX.  Individual elements are compared with TEST."
     (or (null mismatch)
         (= mismatch (- (length seq) (length suffix))))))
 
+(defun as-keyword (string)
+  "Converts the string STRING to a keyword where all characters are
+uppercase or lowercase, taking into account the current readtable
+case."
+  (intern (funcall
+            (if (eq (readtable-case *readtable*) :upcase)
+              #'string-upcase
+              #'string-downcase)
+            string)
+          :keyword))
